#ifndef SRC_USR_UTIL_FILE_H_
#define SRC_USR_UTIL_FILE_H_

#include "usr/util/result.h"

struct jool_result file_to_string(char const *, char **);

#endif /* SRC_USR_UTIL_FILE_H_ */
